==> worker_2.8.4.orig.tar.gz: worker-2.8.4/src/execlass.h <==
/* execlass.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2002 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: execlass.h,v 1.4 2002/09/20 19:50:36 ralf Exp $ */

#ifndef EXECLASS_H
#define EXECLASS_H

#include "wdefines.h"
#include <string>

class ExeClass
{
public:
  typedef enum { EXECUTE_NORMAL = 0,
                 EXECUTE_TERMINAL,
                 EXECUTE_TERMINAL_WAIT,
                 EXECUTE_SHOW_OUTPUT } execlass_execute_t;
  ExeClass( execlass_execute_t exetype, class Worker *w = NULL );
  ~ExeClass();
  void addCommand( const char *format, ... );
  void execute();
  char *getOutput();
  char *getOutput( int *return_error );
  int getReturnCode();
  int getReturnCode( int *return_error );
  void cdDir( const char *dir );
  int getLastError();
protected:
  char *tmpfile, *tmpoutput, *tmperror;
  FILE *fp;
  execlass_execute_t type;
  int lasterror;
  class Worker *worker;
};

int Worker_buildArgvList( const char *commandstr, char ***argvlist );
void Worker_freeArgvList( char **argvlist );
std::string Worker_secureCommandForShell( const char *str );
char *Worker_replaceEnv( const char *str );

#endif

==> worker_2.8.5.orig.tar.gz: worker-2.8.5/src/execlass.h <==
/* execlass.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2002-2004 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: execlass.h,v 1.6 2004/06/13 21:30:48 ralf Exp $ */

#ifndef EXECLASS_H
#define EXECLASS_H

#include "wdefines.h"
#include <string>

class ExeClass
{
public:
  typedef enum { EXECUTE_NORMAL = 0,
                 EXECUTE_TERMINAL,
                 EXECUTE_TERMINAL_WAIT,
                 EXECUTE_SHOW_OUTPUT } execlass_execute_t;
  ExeClass( execlass_execute_t exetype, class Worker *w = NULL );
  ~ExeClass();
  ExeClass( const ExeClass &other );
  ExeClass &operator=( const ExeClass &other );

  void addCommand( const char *format, ... );
  void execute();
  char *getOutput();
  char *getOutput( int *return_error );
  int getOutputAndRV( char **return_output, int *return_value, int *return_error );
  int getReturnCode();
  int getReturnCode( int *return_error );
  void cdDir( const char *dir );
  int getLastError();
protected:
  char *tmpfile, *tmpoutput, *tmperror;
  FILE *fp;
  execlass_execute_t type;
  int lasterror;
  class Worker *worker;
};

int Worker_buildArgvList( const char *commandstr, char ***argvlist );
void Worker_freeArgvList( char **argvlist );
std::string Worker_secureCommandForShell( const char *str );
char *Worker_replaceEnv( const char *str );

#endif
